@@ -1,7 +1,10 @@
-from typing import Any, List, Optional
+from typing import Any, List, Optional, Tuple
 
 from pydantic.main import BaseModel
 
+GraphNode = Tuple[str, dict]
+GraphEdge = Tuple[str, str]
+
 
 class Icon(BaseModel):
     img: str
